@@ -20,6 +20,13 @@ class EWAHPostgresHook(EWAHSQLBaseHook):
     conn_type = "ewah_postgres"
     hook_name = "EWAH PostgreSQL Connection"
 
+    _LIMIT_SQL = """
+        SELECT * FROM ({sql_query}) t
+        ORDER BY {order_by_columns}
+        LIMIT {limit}
+        OFFSET {offset}
+    """
+
     @staticmethod
     def get_ui_field_behaviour() -> dict:
         return {
