@@ -14,6 +14,7 @@ from typing import Optional, List, Dict
 import copy
 import hashlib
 import time
+import sys
 
 
 class EWAHBaseOperator(BaseOperator):
@@ -91,7 +92,51 @@ class EWAHBaseOperator(BaseOperator):
 
     _metadata = {}  # to be updated by operator, if applicable
 
-    def __init__(
+    def __init__(self, *args, **kwargs):
+        try:
+            dag = kwargs.get("dag")  # For error handling below
+            return self.base_init(*args, **kwargs)
+        except Exception as e:
+            # Add useful information to the raised Exception as it will be displayed
+            # in the Airflow UI
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            try:
+                dag_id = (dag or self.dag).dag_id
+            except Exception as e:
+                dag_id = "[unknown]"
+            raise Exception(
+                """
+
+            EWAH Failed to import the DAG.
+
+            \tDAG: {3}
+            \tTask: {4}
+            \tOperator: {2}
+
+            \tException Type: {0}
+            \tError: {1}
+
+            See below for positional and keyword: {5}
+
+            """.replace(
+                    "            ", ""
+                ).format(
+                    exc_type,
+                    str(e),
+                    type(self).__name__,
+                    dag_id,
+                    kwargs["task_id"],
+                    "\n\n\tPositional arguments:\n\t\t"
+                    + "\n\t\t".join(args or ["(None)"])
+                    + "\n\n\tKeyword arguments:\n\t\t"
+                    + "\n\t\t".join(
+                        ["{0}: {1}".format(k, str(v)) for (k, v) in kwargs.items()]
+                        or ["(None)"]
+                    ),
+                )
+            )
+
+    def base_init(
         self,
         source_conn_id,
         dwh_engine,
